==> blancoNLpackGenerator-0.0.97-src.zip: blancoNLpackGenerator/blanco/main/blanco/nlpack/generator/task/BlancoNLpackGeneratorTranslationFragmentToPleiadesTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoNLpackGeneratorTranslationFragmentToPleiades]̃NX
 */
package blanco.nlpack.generator.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessInput;

/**
 * Apache Ant^XN [BlancoNLpackGeneratorTranslationFragmentToPleiades]̃NXB
 *
 * w肳ꂽtOgt@C Pleiades`̃vpeBt@Cɕϊ܂B<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.nlpack.generator.task]BlancoNLpackGeneratorTranslationFragmentToPleiadesBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blanconlpackgeneratortranslationfragmenttopleiades&quot; classname=&quot;blanco.nlpack.generator.task.BlancoNLpackGeneratorTranslationFragmentToPleiadesTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoNLpackGeneratorTranslationFragmentToPleiadesTask extends Task {
    /**
     * w肳ꂽtOgt@C Pleiades`̃vpeBt@Cɕϊ܂B
     */
    protected BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessInput fInput = new BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessInput();

    /**
     * w肳ꂽtOgt@C Pleiades`̃vpeBt@Cɕϊ܂B
     */
    protected boolean fIsFieldSourcefileProcessed = false;

    /**
     * w肳ꂽtOgt@C Pleiades`̃vpeBt@Cɕϊ܂B
     */
    protected boolean fIsFieldTargetfileProcessed = false;

    /**
     * w肳ꂽtOgt@C Pleiades`̃vpeBt@Cɕϊ܂B
     */
    protected boolean fIsFieldSourcedirProcessed = false;

    /**
     * w肳ꂽtOgt@C Pleiades`̃vpeBt@Cɕϊ܂B
     */
    protected boolean fIsFieldTargetdirProcessed = false;

    /**
     * w肳ꂽtOgt@C Pleiades`̃vpeBt@Cɕϊ܂B
     */
    protected boolean fIsFieldContributorProcessed = false;

    /**
     * w肳ꂽtOgt@C Pleiades`̃vpeBt@Cɕϊ܂B
     */
    protected boolean fIsFieldIsoutputdateProcessed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[sourcefile]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * ̓t@CB<br>
     *
     * @param arg Zbgl
     */
    public void setSourcefile(final String arg) {
        fInput.setSourcefile(arg);
        fIsFieldSourcefileProcessed = true;
    }

    /**
     * Ant^XN[sourcefile]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * ̓t@CB<br>
     * ftHgl[conf/BlancoNLpackGeneratorTranslationFragment.csv]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getSourcefile() {
        return fInput.getSourcefile();
    }

    /**
     * Ant^XN[targetfile]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * o̓t@CB<br>
     *
     * @param arg Zbgl
     */
    public void setTargetfile(final String arg) {
        fInput.setTargetfile(arg);
        fIsFieldTargetfileProcessed = true;
    }

    /**
     * Ant^XN[targetfile]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * o̓t@CB<br>
     * ftHgl[tmp/BlancoNLpackGeneratorTranslationFragment.properties]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTargetfile() {
        return fInput.getTargetfile();
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 3<br>
     * ̓t@Ci[ꂽfBNgBsourcefileꂩwB<br>
     *
     * @param arg Zbgl
     */
    public void setSourcedir(final String arg) {
        fInput.setSourcedir(arg);
        fIsFieldSourcedirProcessed = true;
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 3<br>
     * ̓t@Ci[ꂽfBNgBsourcefileꂩwB<br>
     *
     * @return ̃tB[h̒l
     */
    public String getSourcedir() {
        return fInput.getSourcedir();
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 4<br>
     * o̓t@Ci[ꂽfBNgBtargetfileꂩwB<br>
     *
     * @param arg Zbgl
     */
    public void setTargetdir(final String arg) {
        fInput.setTargetdir(arg);
        fIsFieldTargetdirProcessed = true;
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 4<br>
     * o̓t@Ci[ꂽfBNgBtargetfileꂩwB<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTargetdir() {
        return fInput.getTargetdir();
    }

    /**
     * Ant^XN[contributor]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 5<br>
     * v҂̖OB<br>
     *
     * @param arg Zbgl
     */
    public void setContributor(final String arg) {
        fInput.setContributor(arg);
        fIsFieldContributorProcessed = true;
    }

    /**
     * Ant^XN[contributor]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 5<br>
     * v҂̖OB<br>
     * ftHgl[&lt;contributor&gt;]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getContributor() {
        return fInput.getContributor();
    }

    /**
     * Ant^XN[isoutputdate]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 6<br>
     * to͂邩ǂB<br>
     *
     * @param arg Zbgl
     */
    public void setIsoutputdate(final boolean arg) {
        fInput.setIsoutputdate(arg);
        fIsFieldIsoutputdateProcessed = true;
    }

    /**
     * Ant^XN[isoutputdate]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 6<br>
     * to͂邩ǂB<br>
     * ftHgl[true]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getIsoutputdate() {
        return fInput.getIsoutputdate();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    public final void execute() throws BuildException {
        System.out.println("BlancoNLpackGeneratorTranslationFragmentToPleiadesTask begin.");

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- sourcefile:[" + getSourcefile() + "]");
            System.out.println("- targetfile:[" + getTargetfile() + "]");
            System.out.println("- sourcedir:[" + getSourcedir() + "]");
            System.out.println("- targetdir:[" + getTargetdir() + "]");
            System.out.println("- contributor:[" + getContributor() + "]");
            System.out.println("- isoutputdate:[" + getIsoutputdate() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoNLpackGeneratorTranslationFragmentToPleiadesProcessC^tF[X blanco.nlpack.generator.taskpbP[W BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoNLpackGeneratorTranslationFragmentToPleiadesProcess proc = new BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessImpl();
            if (proc.execute(fInput) != BlancoNLpackGeneratorTranslationFragmentToPleiadesBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}

==> blancoNLpackGenerator-0.1.21-src.zip: blancoNLpackGenerator/blanco/main/blanco/nlpack/generator/task/BlancoNLpackGeneratorTranslationFragmentToPleiadesTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoNLpackGeneratorTranslationFragmentToPleiades]̃NX
 */
package blanco.nlpack.generator.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessInput;

/**
 * Apache Ant^XN [BlancoNLpackGeneratorTranslationFragmentToPleiades]̃NXB
 *
 * w肳ꂽtOgt@C Pleiades`̃vpeBt@Cɕϊ܂B<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.nlpack.generator.task]BlancoNLpackGeneratorTranslationFragmentToPleiadesBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blanconlpackgeneratortranslationfragmenttopleiades&quot; classname=&quot;blanco.nlpack.generator.task.BlancoNLpackGeneratorTranslationFragmentToPleiadesTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoNLpackGeneratorTranslationFragmentToPleiadesTask extends Task {
    /**
     * w肳ꂽtOgt@C Pleiades`̃vpeBt@Cɕϊ܂B
     */
    protected BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessInput fInput = new BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessInput();

    /**
     * tB[h [sourcefile] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldSourcefileProcessed = false;

    /**
     * tB[h [targetfile] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldTargetfileProcessed = false;

    /**
     * tB[h [sourcedir] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldSourcedirProcessed = false;

    /**
     * tB[h [targetdir] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldTargetdirProcessed = false;

    /**
     * tB[h [contributor] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldContributorProcessed = false;

    /**
     * tB[h [isoutputdate] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldIsoutputdateProcessed = false;

    /**
     * tB[h [ischeckbundleuriasbabel] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldIscheckbundleuriasbabelProcessed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[sourcefile]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * ̓t@CB<br>
     *
     * @param arg Zbgl
     */
    public void setSourcefile(final String arg) {
        fInput.setSourcefile(arg);
        fIsFieldSourcefileProcessed = true;
    }

    /**
     * Ant^XN[sourcefile]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * ̓t@CB<br>
     * ftHgl[conf/BlancoNLpackGeneratorTranslationFragment.csv]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getSourcefile() {
        return fInput.getSourcefile();
    }

    /**
     * Ant^XN[targetfile]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * o̓t@CB<br>
     *
     * @param arg Zbgl
     */
    public void setTargetfile(final String arg) {
        fInput.setTargetfile(arg);
        fIsFieldTargetfileProcessed = true;
    }

    /**
     * Ant^XN[targetfile]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * o̓t@CB<br>
     * ftHgl[tmp/BlancoNLpackGeneratorTranslationFragment.properties]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTargetfile() {
        return fInput.getTargetfile();
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 3<br>
     * ̓t@Ci[ꂽfBNgBsourcefileꂩwB<br>
     *
     * @param arg Zbgl
     */
    public void setSourcedir(final String arg) {
        fInput.setSourcedir(arg);
        fIsFieldSourcedirProcessed = true;
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 3<br>
     * ̓t@Ci[ꂽfBNgBsourcefileꂩwB<br>
     *
     * @return ̃tB[h̒l
     */
    public String getSourcedir() {
        return fInput.getSourcedir();
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 4<br>
     * o̓t@Ci[ꂽfBNgBtargetfileꂩwB<br>
     *
     * @param arg Zbgl
     */
    public void setTargetdir(final String arg) {
        fInput.setTargetdir(arg);
        fIsFieldTargetdirProcessed = true;
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 4<br>
     * o̓t@Ci[ꂽfBNgBtargetfileꂩwB<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTargetdir() {
        return fInput.getTargetdir();
    }

    /**
     * Ant^XN[contributor]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 5<br>
     * v҂̖OB<br>
     *
     * @param arg Zbgl
     */
    public void setContributor(final String arg) {
        fInput.setContributor(arg);
        fIsFieldContributorProcessed = true;
    }

    /**
     * Ant^XN[contributor]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 5<br>
     * v҂̖OB<br>
     * ftHgl[&lt;contributor&gt;]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getContributor() {
        return fInput.getContributor();
    }

    /**
     * Ant^XN[isoutputdate]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 6<br>
     * to͂邩ǂB<br>
     *
     * @param arg Zbgl
     */
    public void setIsoutputdate(final boolean arg) {
        fInput.setIsoutputdate(arg);
        fIsFieldIsoutputdateProcessed = true;
    }

    /**
     * Ant^XN[isoutputdate]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 6<br>
     * to͂邩ǂB<br>
     * ftHgl[true]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getIsoutputdate() {
        return fInput.getIsoutputdate();
    }

    /**
     * Ant^XN[ischeckbundleuriasbabel]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 7<br>
     * BundleURI babel: n܂Ă邱ƂmF邩ǂB<br>
     *
     * @param arg Zbgl
     */
    public void setIscheckbundleuriasbabel(final boolean arg) {
        fInput.setIscheckbundleuriasbabel(arg);
        fIsFieldIscheckbundleuriasbabelProcessed = true;
    }

    /**
     * Ant^XN[ischeckbundleuriasbabel]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 7<br>
     * BundleURI babel: n܂Ă邱ƂmF邩ǂB<br>
     * ftHgl[true]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getIscheckbundleuriasbabel() {
        return fInput.getIscheckbundleuriasbabel();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    @Override
    public final void execute() throws BuildException {
        System.out.println("BlancoNLpackGeneratorTranslationFragmentToPleiadesTask begin.");

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- sourcefile:[" + getSourcefile() + "]");
            System.out.println("- targetfile:[" + getTargetfile() + "]");
            System.out.println("- sourcedir:[" + getSourcedir() + "]");
            System.out.println("- targetdir:[" + getTargetdir() + "]");
            System.out.println("- contributor:[" + getContributor() + "]");
            System.out.println("- isoutputdate:[" + getIsoutputdate() + "]");
            System.out.println("- ischeckbundleuriasbabel:[" + getIscheckbundleuriasbabel() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoNLpackGeneratorTranslationFragmentToPleiadesProcessC^tF[X blanco.nlpack.generator.taskpbP[W BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoNLpackGeneratorTranslationFragmentToPleiadesProcess proc = new BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessImpl();
            if (proc.execute(fInput) != BlancoNLpackGeneratorTranslationFragmentToPleiadesBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}
